Generate skipped exon events in a GRanges object making all >0 coefs transcripts have a the same exon eventfor the same gene
Source:R/mock_data.R
generate_skipped_exons_restricted.RdGenerate skipped exon events in a GRanges object making all >0 coefs transcripts have a the same exon eventfor the same gene