Skip to contents

Create a sample GRanges with one negative coef transcript and one positive coef transcripts This dataset is designed to include no splicing events

Usage

no_event_mock_data()

Value

A GRanges object with two transcripts per gene and no candidate logic

A GRanges object with two transcripts per gene