Skip to contents

Create a sample GRanges with one negative coef transcript and two positive coef transcripts This dataset is designed to include a skipped exon event at exon_rank 3 and 5 of tx_id 1 happening between both tx_id 2 and tx_id 3

Usage

se_mock_data()

Value

A GRanges object with two transcripts per gene and candidate logic

A GRanges object with two transcripts per gene