Filter candidates that do not overlap any pos_exons, and are internal Then get the left and right exons for each candidate Return a named list with three GRanges objects: candidates, left_exons, right_exons
Source:R/aux_logic.R
candidates_by_non_overlap_directed.RdFilter candidates that do not overlap any pos_exons, and are internal Then get the left and right exons for each candidate Return a named list with three GRanges objects: candidates, left_exons, right_exons