Create a sample GRanges with one negative coef transcript and one positive coef transcripts This dataset is designed to include no splicing events
Source:R/mock_data.R
no_event_mock_data.RdCreate a sample GRanges with one negative coef transcript and one positive coef transcripts This dataset is designed to include no splicing events