Create a sample GRanges with one negative coef transcript and two positive coef transcripts This dataset is designed to include a skipped exon event at exon_rank 3 and 5 of tx_id 1 happening between both tx_id 2 and tx_id 3
Source:R/mock_data.R
se_mock_data.RdCreate a sample GRanges with one negative coef transcript and two positive coef transcripts This dataset is designed to include a skipped exon event at exon_rank 3 and 5 of tx_id 1 happening between both tx_id 2 and tx_id 3